@@ -85,10 +85,10 @@ pub mod managed_arc_slab;
 
 pub use crate::{
     byte_slab::BSlab,
-    slab_arc::SlabArc,
+    slab_arc::{SlabArc, RerooterKey},
     slab_box::SlabBox,
     slab_slice_arc::{SlabSliceArc, SlabStrArc},
-    managed_arc_slab::{ManagedArcSlab, ManagedArcStr},
+    managed_arc_slab::{ManagedArcSlab, ManagedArcStr, Reroot},
 };
 
 #[cfg(test)]
